@@ -13,6 +13,15 @@ class DomainEventBus(MessageBus):
     def retry_publish_only_on_store_queue(self, domain_event: DomainEvent):
         raise NotImplementedError
 
+    @abstractmethod
+    def retry_publish(
+        self,
+        domain_event: DomainEvent,
+        retry_routing_key: str,
+        retry_exchange_name: str = None,
+    ):
+        raise NotImplementedError
+
     def _check_is_domain_event(self, domain_event: DomainEvent):
         if not domain_event or not issubclass(domain_event.__class__, DomainEvent):
             raise TypeError("DomainEventBus only publishes DomainEvent objects")
